# Imported version of egfr_extended.bngl model
# https://doi.org/10.1371/journal.pcbi.1003544.s017
#
# From Hogg et al., "Exact Hybrid Particle/Population Simulation of Rule-Based
# Models of Biochemical Systems", Plos Comp Biol 2014
# https://doi.org/10.1371/journal.pcbi.1003544


from pysb import Model, Monomer, Parameter, Expression, Compartment, Rule, \
    Observable, Initial, MatchOnce, Annotation, ANY, WILD

Model()

Monomer('ERK', ['bind', 'phos', 'loc'], {'loc': ['cyt', 'nuc'],
                                         'phos': ['U', 'P']})
Monomer('Egf', ['r'])
Monomer('Egfr', ['l', 'd', 'Y992', 'Y1068', 'Y1148'], {'Y1068': ['Y', 'pY'],
                                                       'Y992': ['Y', 'pY'],
                                                       'Y1148': ['Y', 'pY']})
Monomer('GAP', ['ras'])
Monomer('Grb2', ['SH2', 'SH3'])
Monomer('MEK', ['bind', 'phos', 'loc'], {'loc': ['cyt', 'nuc'],
                                         'phos': ['U', 'P']})
Monomer('PLCg', ['a', 'b', 'c'], {'c': ['_0', 'I'], 'b': ['_0', 'P']})
Monomer('Raf', ['ras', 'bind', 'phos'], {'phos': ['P', 'U']})
Monomer('Ras', ['nuc', 'raf', 'cat'], {'nuc': ['U', 'GDP', 'GTP']})
Monomer('Shc', ['PTB', 'Y317'], {'Y317': ['Y', 'pY']})
Monomer('Sos', ['dom', 'ras'])

Parameter('NA', 6.0221e+23)
Parameter('f', 0.01)
Parameter('kelim', 0.005)
Parameter('km1', 0.06)
Parameter('km2', 0.1)
Parameter('kp3', 0.5)
Parameter('km3', 4.505)
Parameter('km5', 0.2)
Parameter('kp6', 0.5)
Parameter('km6', 0.025)
Parameter('km7', 0.3)
Parameter('km8', 0.01)
Parameter('km9', 0.05)
Parameter('km10', 0.06)
Parameter('km11', 0.03)
Parameter('km12', 0.0015)
Parameter('km13', 0.6)
Parameter('kp14', 3.0)
Parameter('km14', 0.03)
Parameter('km15', 0.3)
Parameter('km16', 0.005)
Parameter('km17', 0.1)
Parameter('km18', 0.3)
Parameter('km19', 0.0214)
Parameter('km20', 0.12)
Parameter('km21', 0.1)
Parameter('km22', 0.064)
Parameter('km23', 0.1)
Parameter('km24', 0.0429)
Parameter('kp25', 1.0)
Parameter('km25', 0.03)
Parameter('D', 1000.0)
Parameter('khyd', 0.00035)
Parameter('kdgdp', 0.00011)
Parameter('kdgtp', 0.00025)
Parameter('kcatgdp', 3.9)
Parameter('kcatgtp', 0.72)
Parameter('krgdp', 1e-12)
Parameter('kcat_GAP', 5.4)
Parameter('kp_f1', 490000.0)
Parameter('km_f1', 0.049)
Parameter('kp_f2', 650000.0)
Parameter('km_f2', 0.065)
Parameter('kp_f3', 880000.0)
Parameter('km_f3', 0.088)
Parameter('Vm_f6', 0.18)
Parameter('Vm_f5', 0.22)
Parameter('k_f16', 0.01)
Parameter('k_f17', 0.014)
Parameter('kex_f7', 0.61)
Parameter('kin_f7', 0.046)
Parameter('kex_f10', 0.54)
Parameter('kin_f10', 0.04)
Parameter('kex_f9', 0.018)
Parameter('kin_f9', 0.0086)
Parameter('kex_f8', 0.26)
Parameter('kin_f8', 0.035)
Parameter('kex_f11', 0.013)
Parameter('kin_f11', 0.007)

Expression('Vext', 9.4e-13*f)
Expression('Vcyt', 9.4e-13*f)
Expression('Vnuc', 2.2e-13*f)
Expression('Egf_0', 6.8e-7*Vext*NA)
Expression('Egfr_0', 1.0e-7*Vcyt*NA)
Expression('PLCg_0', 1.05e-7*Vcyt*NA)
Expression('Shc_0', 1.5e-7*Vcyt*NA)
Expression('Grb2_0', 8.5e-8*Vcyt*NA)
Expression('Sos_0', 3.4e-8*Vcyt*NA)
Expression('kp1', 3000000.0*Vext**(-1)*NA**(-1))
Expression('kp2', 10000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp5', 30000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp7', 3000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp9', 1500000.0*Vcyt**(-1)*NA**(-1))
Expression('kp10', 10000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp11', 2250000.0*Vcyt**(-1)*NA**(-1))
Expression('kp12', 100000.0*Vcyt**(-1)*NA**(-1))
Expression('kp13', 45000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp15', 450000.0*Vcyt**(-1)*NA**(-1))
Expression('kp17', 3000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp18', 450000.0*Vcyt**(-1)*NA**(-1))
Expression('kp19', 10000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp20', 120000.0*Vcyt**(-1)*NA**(-1))
Expression('kp21', 3000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp22', 30000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp23', 21000000.0*Vcyt**(-1)*NA**(-1))
Expression('kp24', 9000000.0*Vcyt**(-1)*NA**(-1))
Expression('GTP', 0.00018*Vcyt*NA)
Expression('GDP', 1.8e-5*Vcyt*NA)
Expression('GAP_0', 1.0e-9*Vcyt*NA)
Expression('Ras_0', 4.0e-7*Vcyt*NA)
Expression('Raf_0', 1.3e-8*Vcyt*NA)
Expression('MEK_0', 1.4e-6*Vcyt*NA)
Expression('ERK_0', 9.6e-7*Vcyt*NA)
Expression('kagdp', 2300000.0*GDP*NA**(-1)*Vcyt**(-1))
Expression('kagtp', 2200000.0*GTP*NA**(-1)*Vcyt**(-1))
Expression('Kmgdp', 1.56e-7*Vcyt*NA)
Expression('Kmgtp', 1.56e-7*Vcyt*NA)
Expression('kfgdp', 25000.0*D*NA**(-1)*Vcyt**(-1))
Expression('kfgtp', 25000.0*D*NA**(-1)*Vcyt**(-1))
Expression('krgtp', Kmgtp*kfgtp - kcatgtp)
Expression('Km_GAP', 2.3e-7*Vcyt*NA)
Expression('kf_GAP', 100000.0*D*Vcyt**(-1)*NA**(-1))
Expression('kr_GAP', Km_GAP*kf_GAP - kcat_GAP)
Expression('_InitialConc1', 384933*f)
Expression('_InitialConc2', 32825*f)
Expression('_InitialConc3', 84912*f)
Expression('_InitialConc4', 3931*f)
Expression('_InitialConc5', 56608*f)
Expression('_InitialConc6', 59438*f)
Expression('_InitialConc7', 5057*f)
Expression('_InitialConc8', 529*f)
Expression('_InitialConc9', 391192*f)
Expression('_InitialConc10', 43988*f)
Expression('_InitialConc11', 15198*f)
Expression('_InitialConc12', 214883*f)
Expression('_InitialConc13', 9093*f)
Expression('_InitialConc14', 298315*f)
Expression('_InitialConc15', 30348*f)
Expression('_InitialConc16', 60758*f)
Expression('_InitialConc17', 12*f)
Expression('_InitialConc18', 46*f)
Expression('_InitialConc19', 12*f)
Expression('_InitialConc20', 47*f)
Expression('_InitialConc21', 37*f)
Expression('_InitialConc22', 812*f)
Expression('_InitialConc23', 38240*f)
Expression('_InitialConc24', 1489*f)
Expression('_InitialConc25', 24956*f)
Expression('_InitialConc26', 5465*f)
Expression('_InitialConc27', 1858*f)
Expression('_InitialConc28', 646*f)
Expression('_InitialConc29', 72077*f)
Expression('_InitialConc30', 23946*f)
Expression('_rateLaw1', D*kp10)
Expression('_rateLaw2', D*kp11)
Expression('_rateLaw3', D*kp20)
Expression('_rateLaw4', D*kp24)
Expression('_rateLaw5', D*kp19)
Expression('_rateLaw6', kfgdp*D**(-1))
Expression('_rateLaw7', kfgdp*D**(-1))
Expression('_rateLaw8', kfgdp*D**(-1))
Expression('_rateLaw9', kfgtp*D**(-1))
Expression('_rateLaw10', kfgtp*D**(-1))
Expression('_rateLaw11', kfgtp*D**(-1))
Expression('_rateLaw12', kp_f1*NA**(-1)*Vcyt**(-1))
Expression('_rateLaw13', kp_f2*NA**(-1)*Vcyt**(-1))
Expression('_rateLaw14', kp_f3*NA**(-1)*Vcyt**(-1))
Expression('_rateLaw15', kp_f3*NA**(-1)*Vcyt**(-1))

Observable('Dimers', Egfr(d=1) % Egfr(d=1))
Observable('RP', Egfr(Y992=('pY', WILD)) + Egfr(Y1068=('pY', WILD)) + Egfr(Y1148=('pY', WILD)))
Observable('Shc_Grb', Shc(Y317=('pY', 1)) % Grb2(SH2=1))
Observable('Shc_Grb_Sos', Shc(Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2))
Observable('R_Grb2', Egfr(Y1068=('pY', 1)) % Grb2(SH2=1))
Observable('R_Shc', Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317='Y'))
Observable('R_ShcP', Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', WILD)))
Observable('R_pY992', Egfr(Y992=('pY', WILD)))
Observable('R_PLCg', Egfr(Y992=('pY', 1)) % PLCg(a=1))
Observable('ShcP', Shc(Y317=('pY', WILD)))
Observable('PLCgP', PLCg(b='P', c='_0'))
Observable('PLCgPI', PLCg(b='P', c='I'))
Observable('Sos_mem', Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2) + Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2))
Observable('Sos_cyt', Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2) + Grb2(SH2=None, SH3=1) % Sos(dom=1) + Sos(dom=None))
Observable('RasGDP', Ras(nuc='GDP'))
Observable('RasGTP', Ras(nuc='GTP'))
Observable('RafU', Raf(phos=('U', WILD)))
Observable('RafP', Raf(phos=('P', WILD)))
Observable('MEK_act', MEK(phos=('P', WILD)))
Observable('ERK_act', ERK(phos=('P', WILD)))
Observable('MEK_nuc', MEK(loc='nuc'))
Observable('ERK_nuc', ERK(loc='nuc'))
Observable('MEK_P_nuc', MEK(phos=('P', WILD), loc='nuc'))
Observable('ERK_P_nuc', ERK(phos=('P', WILD), loc='nuc'))
Observable('Egf_tot', Egf())
Observable('Egfr_tot', Egfr())
Observable('PLCg_tot', PLCg())
Observable('Shc_tot', Shc())
Observable('Grb2_tot', Grb2())
Observable('Sos_tot', Sos())
Observable('GAP_tot', GAP())
Observable('Ras_tot', Ras())
Observable('Raf_tot', Raf())
Observable('MEK_tot', MEK())
Observable('ERK_tot', ERK())

Rule('EGF_elim', Egf(r=None) >> None, kelim)
Rule('B1', Egfr(l=None, d=None) + Egf(r=None) | Egfr(l=1, d=None) % Egf(r=1), kp1, km1)
Rule('B2', Egfr(l=ANY, d=None) + Egfr(l=ANY, d=None) | Egfr(l=ANY, d=1) % Egfr(l=ANY, d=1), kp2, km2)
Rule('B3p_992', Egfr(d=ANY, Y992='Y') >> Egfr(d=ANY, Y992='pY'), kp3)
Rule('B3p_1068', Egfr(d=ANY, Y1068='Y') >> Egfr(d=ANY, Y1068='pY'), kp3)
Rule('B3p_1148', Egfr(d=ANY, Y1148='Y') >> Egfr(d=ANY, Y1148='pY'), kp3)
Rule('B3m_992', Egfr(Y992='pY') >> Egfr(Y992='Y'), km3)
Rule('B3m_1068', Egfr(Y1068='pY') >> Egfr(Y1068='Y'), km3)
Rule('B3m_1148', Egfr(Y1148='pY') >> Egfr(Y1148='Y'), km3)
Rule('B14p', Egfr(d=ANY, Y1148=('pY', 1)) % Shc(PTB=1, Y317='Y') >> Egfr(d=ANY, Y1148=('pY', 1)) % Shc(PTB=1, Y317='pY'), kp14)
Rule('B14m', Shc(PTB=ANY, Y317='pY') >> Shc(PTB=ANY, Y317='Y'), km14)
Rule('B6p', Egfr(d=ANY, Y992=('pY', 1)) % PLCg(a=1, b='_0') >> Egfr(d=ANY, Y992=('pY', 1)) % PLCg(a=1, b='P'), kp6)
Rule('B6m', Egfr(Y992=('pY', 1)) % PLCg(a=1, b='P') >> Egfr(Y992=('pY', 1)) % PLCg(a=1, b='_0'), km6)
Rule('B5', Egfr(Y992='pY') + PLCg(a=None, b='_0', c='_0') | Egfr(Y992=('pY', 1)) % PLCg(a=1, b='_0', c='_0'), kp5, km5)
Rule('B7', Egfr(Y992='pY') + PLCg(a=None, b='P', c='_0') | Egfr(Y992=('pY', 1)) % PLCg(a=1, b='P', c='_0'), kp7, km7)
Rule('B9', Egfr(Y1068='pY') + Grb2(SH2=None, SH3=None) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=None), kp9, km9)
Rule('B10_cyt', Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=None) + Sos(dom=None, ras=None) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None), kp10, km10)
Rule('B10_mem', Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=None) + Sos(dom=None, ras=ANY) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=ANY), _rateLaw1, km10)
Rule('B11_cyt', Egfr(Y1068='pY') + Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=None) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None), kp11, km11)
Rule('B11_mem', Egfr(Y1068='pY') + Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=ANY) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=ANY), _rateLaw2, km11)
Rule('B13', Egfr(Y1148='pY') + Shc(PTB=None, Y317='Y') | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317='Y'), kp13, km13)
Rule('B15', Egfr(Y1148='pY') + Shc(PTB=None, Y317='pY') | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317='pY'), kp15, km15)
Rule('B18', Egfr(Y1148='pY') + Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=None) | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', 2)) % Grb2(SH2=2, SH3=None), kp18, km18)
Rule('B20_cyt', Egfr(Y1148='pY') + Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', 2)) % Grb2(SH2=2, SH3=3) % Sos(dom=3, ras=None), kp20, km20)
Rule('B20_mem', Egfr(Y1148='pY') + Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=ANY) | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', 2)) % Grb2(SH2=2, SH3=3) % Sos(dom=3, ras=ANY), _rateLaw3, km20)
Rule('B17', Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317='pY') + Grb2(SH2=None, SH3=None) | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', 2)) % Grb2(SH2=2, SH3=None), kp17, km17)
Rule('B24_cyt', Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317='pY') + Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=None) | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', 2)) % Grb2(SH2=2, SH3=3) % Sos(dom=3, ras=None), kp24, km24)
Rule('B24_mem', Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317='pY') + Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=ANY) | Egfr(Y1148=('pY', 1)) % Shc(PTB=1, Y317=('pY', 2)) % Grb2(SH2=2, SH3=3) % Sos(dom=3, ras=ANY), _rateLaw4, km24)
Rule('B19_cyt', Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=None) + Sos(dom=None, ras=None) | Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None), kp19, km19)
Rule('B19_mem', Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=None) + Sos(dom=None, ras=ANY) | Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=ANY), _rateLaw5, km19)
Rule('B21', Shc(PTB=None, Y317='pY') + Grb2(SH2=None, SH3=None) | Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=None), kp21, km21)
Rule('B23', Shc(PTB=None, Y317='pY') + Grb2(SH2=None, SH3=1) % Sos(dom=1) | Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2), kp23, km23)
Rule('B16', Shc(PTB=None, Y317='pY') >> Shc(PTB=None, Y317='Y'), km16)
Rule('B12', Grb2(SH2=None, SH3=None) + Sos(dom=None) | Grb2(SH2=None, SH3=1) % Sos(dom=1), kp12, km12)
Rule('B22', Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=None) + Sos(dom=None) | Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2), kp22, km22)
Rule('B8', PLCg(a=None, b='P', c='_0') >> PLCg(a=None, b='_0', c='_0'), km8)
Rule('B25', PLCg(a=None, b='P', c='_0') | PLCg(a=None, b='P', c='I'), kp25, km25)
Rule('S1', Ras(nuc='U', raf=None, cat=None) | Ras(nuc='GDP', raf=None, cat=None), kagdp, kdgdp)
Rule('S2', Ras(nuc='U', raf=None, cat=None) | Ras(nuc='GTP', raf=None, cat=None), kagtp, kdgtp)
Rule('S3', Ras(nuc='GTP', raf=None, cat=None) >> Ras(nuc='GDP', raf=None, cat=None), khyd)
Rule('S4', Sos(dom=None, ras=None) + Ras(nuc='GDP', raf=None, cat=None) | Sos(dom=None, ras=1) % Ras(nuc='GDP', raf=None, cat=1), _rateLaw6, krgdp)
Rule('S5', Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=None) + Ras(nuc='GDP', raf=None, cat=None) | Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=2) % Ras(nuc='GDP', raf=None, cat=2), _rateLaw7, krgdp)
Rule('S6', Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) + Ras(nuc='GDP', raf=None, cat=None) | Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=3) % Ras(nuc='GDP', raf=None, cat=3), _rateLaw8, krgdp)
Rule('S7', Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) + Ras(nuc='GDP', raf=None, cat=None) | Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=3) % Ras(nuc='GDP', raf=None, cat=3), kfgdp, krgdp)
Rule('S8', Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) + Ras(nuc='GDP', raf=None, cat=None) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=3) % Ras(nuc='GDP', raf=None, cat=3), kfgdp, krgdp)
Rule('S9', Sos(dom=None, ras=None) + Ras(nuc='GTP', raf=None, cat=None) | Sos(dom=None, ras=1) % Ras(nuc='GTP', raf=None, cat=1), _rateLaw9, krgtp)
Rule('S10', Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=None) + Ras(nuc='GTP', raf=None, cat=None) | Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=2) % Ras(nuc='GTP', raf=None, cat=2), _rateLaw10, krgtp)
Rule('S11', Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) + Ras(nuc='GTP', raf=None, cat=None) | Shc(PTB=None, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=3) % Ras(nuc='GTP', raf=None, cat=3), _rateLaw11, krgtp)
Rule('S12', Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) + Ras(nuc='GTP', raf=None, cat=None) | Shc(PTB=ANY, Y317=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=3) % Ras(nuc='GTP', raf=None, cat=3), kfgtp, krgtp)
Rule('S13', Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=None) + Ras(nuc='GTP', raf=None, cat=None) | Egfr(Y1068=('pY', 1)) % Grb2(SH2=1, SH3=2) % Sos(dom=2, ras=3) % Ras(nuc='GTP', raf=None, cat=3), kfgtp, krgtp)
Rule('S14', Sos(ras=1) % Ras(nuc='GDP', raf=None, cat=1) | Sos(ras=1) % Ras(nuc='GTP', raf=None, cat=1), kcatgdp, kcatgtp)
Rule('S15', Ras(nuc='GTP', raf=None, cat=None) + GAP(ras=None) | Ras(nuc='GTP', raf=None, cat=1) % GAP(ras=1), kf_GAP, kr_GAP)
Rule('S16', Ras(nuc='GTP', raf=None, cat=1) % GAP(ras=1) >> Ras(nuc='GDP', raf=None, cat=None) + GAP(ras=None), kcat_GAP)
Rule('F1', Ras(nuc='GTP', raf=None, cat=None) + Raf(ras=None, bind=None, phos='U') | Ras(nuc='GTP', raf=1, cat=None) % Raf(ras=1, bind=None, phos='P'), _rateLaw12, km_f1)
Rule('F2', Ras(nuc='GTP', raf=1) % Raf(ras=1, bind=None, phos='P') + MEK(bind=None, phos='U', loc='cyt') | Ras(nuc='GTP', raf=1) % Raf(ras=1, bind=2, phos='P') % MEK(bind=2, phos='U', loc='cyt'), _rateLaw13, km_f2)
Rule('F6', Ras(nuc='GTP', raf=1) % Raf(ras=1, bind=2, phos='P') % MEK(bind=2, phos='U', loc='cyt') >> Ras(nuc='GTP', raf=1) % Raf(ras=1, bind=None, phos='P') + MEK(bind=None, phos='P', loc='cyt'), Vm_f6)
Rule('F3', MEK(bind=None, loc='cyt') + ERK(bind=None, phos='U', loc='cyt') | MEK(bind=1, loc='cyt') % ERK(bind=1, phos='U', loc='cyt'), _rateLaw14, km_f3)
Rule('F13', MEK(bind=None, loc='nuc') + ERK(bind=None, phos='U', loc='nuc') | MEK(bind=1, loc='nuc') % ERK(bind=1, phos='U', loc='nuc'), _rateLaw15, km_f3)
Rule('F5', MEK(bind=1, phos='P') % ERK(bind=1, phos='U') >> MEK(bind=None, phos='P') + ERK(bind=None, phos='P'), Vm_f5)
Rule('F7', MEK(bind=None, phos='U', loc='nuc') | MEK(bind=None, phos='U', loc='cyt'), kex_f7, kin_f7)
Rule('F10', MEK(bind=None, phos='P', loc='nuc') | MEK(bind=None, phos='P', loc='cyt'), kex_f10, kin_f10)
Rule('F8', MEK(bind=1, loc='nuc') % ERK(bind=1, loc='nuc') | MEK(bind=1, loc='cyt') % ERK(bind=1, loc='cyt'), kex_f8, kin_f8)
Rule('F9', ERK(bind=None, phos='U', loc='nuc') | ERK(bind=None, phos='U', loc='cyt'), kex_f9, kin_f9)
Rule('F11', ERK(bind=None, phos='P', loc='nuc') | ERK(bind=None, phos='P', loc='cyt'), kex_f11, kin_f11)
Rule('F16', MEK(bind=None, phos='P') >> MEK(bind=None, phos='U'), k_f16)
Rule('F17', ERK(bind=None, phos='P') >> ERK(bind=None, phos='U'), k_f17)

Initial(Egf(r=None), _InitialConc1)
Initial(Grb2(SH2=None, SH3=None), _InitialConc2)
Initial(Shc(PTB=None, Y317='Y'), _InitialConc3)
Initial(Sos(dom=None, ras=None), _InitialConc4)
Initial(Egfr(l=None, d=None, Y992='Y', Y1068='Y', Y1148='Y'), _InitialConc5)
Initial(PLCg(a=None, b='_0', c='_0'), _InitialConc6)
Initial(Raf(ras=None, bind=None, phos='U'), _InitialConc7)
Initial(GAP(ras=None), _InitialConc8)
Initial(MEK(bind=None, phos='U', loc='cyt'), _InitialConc9)
Initial(ERK(bind=None, phos='U', loc='cyt'), _InitialConc10)
Initial(Grb2(SH2=None, SH3=1) % Sos(dom=1, ras=None), _InitialConc11)
Initial(Ras(nuc='GDP', raf=None, cat=None), _InitialConc12)
Initial(Ras(nuc='GTP', raf=None, cat=None), _InitialConc13)
Initial(ERK(bind=1, phos='U', loc='cyt') % MEK(bind=1, phos='U', loc='cyt'), _InitialConc14)
Initial(MEK(bind=None, phos='U', loc='nuc'), _InitialConc15)
Initial(ERK(bind=None, phos='U', loc='nuc'), _InitialConc16)
Initial(Ras(nuc='GDP', raf=None, cat=1) % Sos(dom=None, ras=1), _InitialConc17)
Initial(Grb2(SH2=None, SH3=1) % Ras(nuc='GDP', raf=None, cat=2) % Sos(dom=1, ras=2), _InitialConc18)
Initial(Ras(nuc='GTP', raf=None, cat=1) % Sos(dom=None, ras=1), _InitialConc19)
Initial(Grb2(SH2=None, SH3=1) % Ras(nuc='GTP', raf=None, cat=2) % Sos(dom=1, ras=2), _InitialConc20)
Initial(GAP(ras=1) % Ras(nuc='GTP', raf=None, cat=1), _InitialConc21)
Initial(Raf(ras=1, bind=None, phos='P') % Ras(nuc='GTP', raf=1, cat=None), _InitialConc22)
Initial(ERK(bind=1, phos='U', loc='nuc') % MEK(bind=1, phos='U', loc='nuc'), _InitialConc23)
Initial(MEK(bind=1, phos='U', loc='cyt') % Raf(ras=2, bind=1, phos='P') % Ras(nuc='GTP', raf=2, cat=None), _InitialConc24)
Initial(MEK(bind=None, phos='P', loc='cyt'), _InitialConc25)
Initial(ERK(bind=1, phos='U', loc='cyt') % MEK(bind=1, phos='P', loc='cyt'), _InitialConc26)
Initial(MEK(bind=None, phos='P', loc='nuc'), _InitialConc27)
Initial(ERK(bind=1, phos='U', loc='nuc') % MEK(bind=1, phos='P', loc='nuc'), _InitialConc28)
Initial(ERK(bind=None, phos='P', loc='cyt'), _InitialConc29)
Initial(ERK(bind=None, phos='P', loc='nuc'), _InitialConc30)
